@@ -9,22 +9,17 @@
 #include "event.h"
 #include "dictstat.h"
 #include "locking.h"
-#include "shared.h"
 
 int sort_by_dictstat (const void *s1, const void *s2)
 {
   dictstat_t *d1 = (dictstat_t *) s1;
   dictstat_t *d2 = (dictstat_t *) s2;
 
+  #if defined (__linux__) || defined (__CYGWIN__)
+  d2->stat.st_atim = d1->stat.st_atim;
+  #else
   d2->stat.st_atime = d1->stat.st_atime;
-
-  const int rc_from = strcmp (d1->encoding_from, d2->encoding_from);
-
-  if (rc_from != 0) return rc_from;
-
-  const int rc_to = strcmp (d1->encoding_to, d2->encoding_to);
-
-  if (rc_to != 0) return rc_to;
+  #endif
 
   return memcmp (&d1->stat, &d2->stat, sizeof (struct stat));
 }
@@ -47,13 +42,23 @@ int dictstat_init (hashcat_ctx_t *hashcat_ctx)
 
   if (user_options->attack_mode == ATTACK_MODE_BF) return 0;
 
-  if (user_options->hash_mode == 3000) return 0; // this mode virtually creates words in the wordlists
-
   dictstat_ctx->enabled  = true;
+  dictstat_ctx->filename = (char *)       hcmalloc (HCBUFSIZ_TINY);
   dictstat_ctx->base     = (dictstat_t *) hccalloc (MAX_DICTSTAT, sizeof (dictstat_t));
   dictstat_ctx->cnt      = 0;
 
-  hc_asprintf (&dictstat_ctx->filename, "%s/hashcat.dictstat", folder_config->profile_dir);
+  snprintf (dictstat_ctx->filename, HCBUFSIZ_TINY - 1, "%s/hashcat.dictstat", folder_config->profile_dir);
+
+  FILE *fp = fopen (dictstat_ctx->filename, "ab");
+
+  if (fp == NULL)
+  {
+    event_log_error (hashcat_ctx, "%s: %s", dictstat_ctx->filename, strerror (errno));
+
+    return -1;
+  }
+
+  fclose (fp);
 
   return 0;
 }
