@@ -47,7 +47,7 @@ static void mp_css_split_cnt (hashcat_ctx_t *hashcat_ctx, const u32 css_cnt_orig
     }
     else
     {
-      if ((hashconfig->opts_type & OPTS_TYPE_PT_UTF16LE) || (hashconfig->opts_type & OPTS_TYPE_PT_UTF16BE))
+      if (hashconfig->opts_type & OPTS_TYPE_PT_UNICODE)
       {
         if (css_cnt_orig == 8 || css_cnt_orig == 10)
         {
@@ -122,50 +122,26 @@ static int mp_css_append_salt (hashcat_ctx_t *hashcat_ctx, salt_t *salt_buf)
   return 0;
 }
 
-static int mp_css_utf16le_expand (hashcat_ctx_t *hashcat_ctx)
+static int mp_css_unicode_expand (hashcat_ctx_t *hashcat_ctx)
 {
   mask_ctx_t *mask_ctx = hashcat_ctx->mask_ctx;
 
-  u32 css_cnt_utf16le = mask_ctx->css_cnt * 2;
+  u32 css_cnt_unicode = mask_ctx->css_cnt * 2;
 
-  cs_t *css_buf_utf16le = (cs_t *) hccalloc (css_cnt_utf16le, sizeof (cs_t));
+  cs_t *css_buf_unicode = (cs_t *) hccalloc (css_cnt_unicode, sizeof (cs_t));
 
   for (u32 i = 0, j = 0; i < mask_ctx->css_cnt; i += 1, j += 2)
   {
-    memcpy (&css_buf_utf16le[j + 0], &mask_ctx->css_buf[i], sizeof (cs_t));
+    memcpy (&css_buf_unicode[j + 0], &mask_ctx->css_buf[i], sizeof (cs_t));
 
-    css_buf_utf16le[j + 1].cs_buf[0] = 0;
-    css_buf_utf16le[j + 1].cs_len    = 1;
+    css_buf_unicode[j + 1].cs_buf[0] = 0;
+    css_buf_unicode[j + 1].cs_len    = 1;
   }
 
   hcfree (mask_ctx->css_buf);
 
-  mask_ctx->css_buf = css_buf_utf16le;
-  mask_ctx->css_cnt = css_cnt_utf16le;
-
-  return 0;
-}
-
-static int mp_css_utf16be_expand (hashcat_ctx_t *hashcat_ctx)
-{
-  mask_ctx_t *mask_ctx = hashcat_ctx->mask_ctx;
-
-  u32 css_cnt_utf16be = mask_ctx->css_cnt * 2;
-
-  cs_t *css_buf_utf16be = (cs_t *) hccalloc (css_cnt_utf16be, sizeof (cs_t));
-
-  for (u32 i = 0, j = 0; i < mask_ctx->css_cnt; i += 1, j += 2)
-  {
-    css_buf_utf16be[j + 0].cs_buf[0] = 0;
-    css_buf_utf16be[j + 0].cs_len    = 1;
-
-    memcpy (&css_buf_utf16be[j + 1], &mask_ctx->css_buf[i], sizeof (cs_t));
-  }
-
-  hcfree (mask_ctx->css_buf);
-
-  mask_ctx->css_buf = css_buf_utf16be;
-  mask_ctx->css_cnt = css_cnt_utf16be;
+  mask_ctx->css_buf = css_buf_unicode;
+  mask_ctx->css_cnt = css_cnt_unicode;
 
   return 0;
 }
@@ -176,7 +152,7 @@ static int mp_css_to_uniq_tbl (hashcat_ctx_t *hashcat_ctx, u32 css_cnt, cs_t *cs
 
   if (css_cnt > SP_PW_MAX)
   {
-    event_log_error (hashcat_ctx, "Mask length is too long.");
+    event_log_error (hashcat_ctx, "Mask length is too long");
 
     return -1;
   }
@@ -276,16 +252,16 @@ static int mp_expand (hashcat_ctx_t *hashcat_ctx, char *in_buf, size_t in_len, c
                   break;
         case 'H': rc = mp_add_cs_buf (hashcat_ctx, mp_sys[7].cs_buf, mp_sys[7].cs_len, mp_usr, mp_usr_offset);
                   break;
-        case '1': if (mp_usr[0].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 1 is undefined."); return -1; }
+        case '1': if (mp_usr[0].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 1 is undefined"); return -1; }
                   rc = mp_add_cs_buf (hashcat_ctx, mp_usr[0].cs_buf, mp_usr[0].cs_len, mp_usr, mp_usr_offset);
                   break;
-        case '2': if (mp_usr[1].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 2 is undefined."); return -1; }
+        case '2': if (mp_usr[1].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 2 is undefined"); return -1; }
                   rc = mp_add_cs_buf (hashcat_ctx, mp_usr[1].cs_buf, mp_usr[1].cs_len, mp_usr, mp_usr_offset);
                   break;
-        case '3': if (mp_usr[2].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 3 is undefined."); return -1; }
+        case '3': if (mp_usr[2].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 3 is undefined"); return -1; }
                   rc = mp_add_cs_buf (hashcat_ctx, mp_usr[2].cs_buf, mp_usr[2].cs_len, mp_usr, mp_usr_offset);
                   break;
-        case '4': if (mp_usr[3].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 4 is undefined."); return -1; }
+        case '4': if (mp_usr[3].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 4 is undefined"); return -1; }
                   rc = mp_add_cs_buf (hashcat_ctx, mp_usr[3].cs_buf, mp_usr[3].cs_len, mp_usr, mp_usr_offset);
                   break;
         case '?': rc = mp_add_cs_buf (hashcat_ctx, &p0, 1, mp_usr, mp_usr_offset);
@@ -304,7 +280,7 @@ static int mp_expand (hashcat_ctx_t *hashcat_ctx, char *in_buf, size_t in_len, c
 
         if (in_pos == in_len)
         {
-          event_log_error (hashcat_ctx, "The hex-charset option expects exactly 2 hexadecimal chars. Failed mask: %s", in_buf);
+          event_log_error (hashcat_ctx, "The hex-charset option always expects couples of exactly 2 hexadecimal chars, failed mask: %s", in_buf);
 
           return -1;
         }
@@ -382,16 +358,16 @@ static int mp_gen_css (hashcat_ctx_t *hashcat_ctx, char *mask_buf, size_t mask_l
                   break;
         case 'H': rc = mp_add_cs_buf (hashcat_ctx, mp_sys[7].cs_buf, mp_sys[7].cs_len, css_buf, css_pos);
                   break;
-        case '1': if (mp_usr[0].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 1 is undefined."); return -1; }
+        case '1': if (mp_usr[0].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 1 is undefined"); return -1; }
                   rc = mp_add_cs_buf (hashcat_ctx, mp_usr[0].cs_buf, mp_usr[0].cs_len, css_buf, css_pos);
                   break;
-        case '2': if (mp_usr[1].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 2 is undefined."); return -1; }
+        case '2': if (mp_usr[1].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 2 is undefined"); return -1; }
                   rc = mp_add_cs_buf (hashcat_ctx, mp_usr[1].cs_buf, mp_usr[1].cs_len, css_buf, css_pos);
                   break;
-        case '3': if (mp_usr[2].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 3 is undefined."); return -1; }
+        case '3': if (mp_usr[2].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 3 is undefined"); return -1; }
                   rc = mp_add_cs_buf (hashcat_ctx, mp_usr[2].cs_buf, mp_usr[2].cs_len, css_buf, css_pos);
                   break;
-        case '4': if (mp_usr[3].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 4 is undefined."); return -1; }
+        case '4': if (mp_usr[3].cs_len == 0) { event_log_error (hashcat_ctx, "Custom-charset 4 is undefined"); return -1; }
                   rc = mp_add_cs_buf (hashcat_ctx, mp_usr[3].cs_buf, mp_usr[3].cs_len, css_buf, css_pos);
                   break;
         case '?': rc = mp_add_cs_buf (hashcat_ctx, &chr, 1, css_buf, css_pos);
@@ -412,7 +388,7 @@ static int mp_gen_css (hashcat_ctx_t *hashcat_ctx, char *mask_buf, size_t mask_l
 
         if (mask_pos == mask_len)
         {
-          event_log_error (hashcat_ctx, "The hex-charset option expects exactly 2 hexadecimal chars. Failed mask: %s", mask_buf);
+          event_log_error (hashcat_ctx, "The hex-charset option always expects couples of exactly 2 hexadecimal chars, failed mask: %s", mask_buf);
 
           return -1;
         }
@@ -450,7 +426,7 @@ static int mp_gen_css (hashcat_ctx_t *hashcat_ctx, char *mask_buf, size_t mask_l
 
   if (css_pos == 0)
   {
-    event_log_error (hashcat_ctx, "Invalid mask length (0).");
+    event_log_error (hashcat_ctx, "Invalid mask length (0)");
 
     return -1;
   }
@@ -492,7 +468,7 @@ static int mp_get_truncated_mask (hashcat_ctx_t *hashcat_ctx, const char *mask_b
 
         if (mask_pos == mask_len)
         {
-          event_log_error (hashcat_ctx, "The hex-charset option expects exactly 2 hexadecimal chars. Failed mask: %s", mask_buf);
+          event_log_error (hashcat_ctx, "The hex-charset option always expects couples of exactly 2 hexadecimal chars, failed mask: %s", mask_buf);
 
           return -1;
         }
@@ -555,13 +531,13 @@ static void mp_setup_sys (cs_t *mp_sys)
                                                    mp_sys[7].cs_len = pos; }
 }
 
-static int mp_setup_usr (hashcat_ctx_t *hashcat_ctx, cs_t *mp_sys, cs_t *mp_usr, char *buf, const u32 userindex)
+static int mp_setup_usr (hashcat_ctx_t *hashcat_ctx, cs_t *mp_sys, cs_t *mp_usr, char *buf, u32 index)
 {
   FILE *fp = fopen (buf, "rb");
 
   if (fp == NULL) // feof() in case if file is empty
   {
-    const int rc = mp_expand (hashcat_ctx, buf, strlen (buf), mp_sys, mp_usr, userindex, 1);
+    const int rc = mp_expand (hashcat_ctx, buf, strlen (buf), mp_sys, mp_usr, index, 1);
 
     if (rc == -1) return -1;
   }
@@ -573,7 +549,7 @@ static int mp_setup_usr (hashcat_ctx_t *hashcat_ctx, cs_t *mp_sys, cs_t *mp_usr,
 
     if (!feof (fp))
     {
-      event_log_error (hashcat_ctx, "%s: Custom charset file is too large.", buf);
+      event_log_error (hashcat_ctx, "%s: Custom charset file is too large", buf);
 
       fclose (fp);
 
@@ -586,23 +562,21 @@ static int mp_setup_usr (hashcat_ctx_t *hashcat_ctx, cs_t *mp_sys, cs_t *mp_usr,
 
     if (nread == 0)
     {
-      event_log_error (hashcat_ctx, "%s: Custom charset file is empty.", buf);
+      event_log_error (hashcat_ctx, "%s: Custom charset file is empty", buf);
 
       return -1;
     }
 
-    mp_file[nread] = 0;
-
-    const size_t len = superchop_with_length (mp_file, nread);
+    const size_t len = in_superchop (mp_file);
 
     if (len == 0)
     {
-      event_log_error (hashcat_ctx, "%s: Custom charset file is corrupted.", buf);
+      event_log_error (hashcat_ctx, "%s: Custom charset file is corrupted", buf);
 
       return -1;
     }
 
-    const int rc = mp_expand (hashcat_ctx, mp_file, len, mp_sys, mp_usr, userindex, 0);
+    const int rc = mp_expand (hashcat_ctx, mp_file, len, mp_sys, mp_usr, index, 0);
 
     if (rc == -1) return -1;
   }
@@ -610,11 +584,11 @@ static int mp_setup_usr (hashcat_ctx_t *hashcat_ctx, cs_t *mp_sys, cs_t *mp_usr,
   return 0;
 }
 
-static void mp_reset_usr (cs_t *mp_usr, const u32 userindex)
+static void mp_reset_usr (cs_t *mp_usr, u32 index)
 {
-  mp_usr[userindex].cs_len = 0;
+  mp_usr[index].cs_len = 0;
 
-  memset (mp_usr[userindex].cs_buf, 0, sizeof (mp_usr[userindex].cs_buf));
+  memset (mp_usr[index].cs_buf, 0, sizeof (mp_usr[index].cs_buf));
 }
 
 static int sp_setup_tbl (hashcat_ctx_t *hashcat_ctx)
@@ -669,11 +643,11 @@ static int sp_setup_tbl (hashcat_ctx_t *hashcat_ctx)
    * Load hcstats File
    */
 
-  char hcstat_tmp[256];
-
   if (hcstat == NULL)
   {
-    snprintf (hcstat_tmp, sizeof (hcstat_tmp), "%s/%s", shared_dir, SP_HCSTAT);
+    char hcstat_tmp[256] = { 0 };
+
+    snprintf (hcstat_tmp, sizeof (hcstat_tmp) - 1, "%s/%s", shared_dir, SP_HCSTAT);
 
     hcstat = hcstat_tmp;
   }
@@ -689,7 +663,7 @@ static int sp_setup_tbl (hashcat_ctx_t *hashcat_ctx)
 
   if (fread (root_stats_buf, sizeof (u64), SP_ROOT_CNT, fd) != SP_ROOT_CNT)
   {
-    event_log_error (hashcat_ctx, "%s: Could not load data.", hcstat);
+    event_log_error (hashcat_ctx, "%s: Could not load data", hcstat);
 
     fclose (fd);
 
@@ -698,7 +672,7 @@ static int sp_setup_tbl (hashcat_ctx_t *hashcat_ctx)
 
   if (fread (markov_stats_buf, sizeof (u64), SP_MARKOV_CNT, fd) != SP_MARKOV_CNT)
   {
-    event_log_error (hashcat_ctx, "%s: Could not load data.", hcstat);
+    event_log_error (hashcat_ctx, "%s: Could not load data", hcstat);
 
     fclose (fd);
 
@@ -831,7 +805,7 @@ static int sp_setup_tbl (hashcat_ctx_t *hashcat_ctx)
   return 0;
 }
 
-static int sp_get_sum (u32 start, u32 stop, cs_t *root_css_buf, u64 *result)
+static u64 sp_get_sum (u32 start, u32 stop, cs_t *root_css_buf)
 {
   u64 sum = 1;
 
@@ -839,14 +813,10 @@ static int sp_get_sum (u32 start, u32 stop, cs_t *root_css_buf, u64 *result)
 
   for (i = start; i < stop; i++)
   {
-    if (overflow_check_u64_mul (sum, root_css_buf[i].cs_len) == false) return -1;
-
     sum *= root_css_buf[i].cs_len;
   }
 
-  *result = sum;
-
-  return 0;
+  return (sum);
 }
 
 static void sp_tbl_to_css (hcstat_table_t *root_table_buf, hcstat_table_t *markov_table_buf, cs_t *root_css_buf, cs_t *markov_css_buf, u32 threshold, u32 uniq_tbls[SP_PW_MAX][CHARSIZ])
@@ -957,7 +927,7 @@ static int mask_append_final (hashcat_ctx_t *hashcat_ctx, const char *mask)
   return 0;
 }
 
-static int mask_append (hashcat_ctx_t *hashcat_ctx, const char *mask, const char *prepend)
+static int mask_append (hashcat_ctx_t *hashcat_ctx, const char *mask)
 {
   hashconfig_t   *hashconfig   = hashcat_ctx->hashconfig;
   user_options_t *user_options = hashcat_ctx->user_options;
@@ -966,71 +936,34 @@ static int mask_append (hashcat_ctx_t *hashcat_ctx, const char *mask, const char
   {
     const u32 mask_length = mp_get_length (mask);
 
+    const u32 pw_min = hashconfig->pw_min;
+    const u32 pw_max = hashconfig->pw_max;
+
     u32 increment_min = user_options->increment_min;
     u32 increment_max = user_options->increment_max;
 
+    increment_min = MAX (increment_min, pw_min);
+    increment_max = MIN (increment_max, pw_max);
     increment_max = MIN (increment_max, mask_length);
 
-    if (user_options->attack_mode == ATTACK_MODE_BF)
-    {
-      const u32 pw_min = hashconfig->pw_min;
-      const u32 pw_max = hashconfig->pw_max;
-
-      increment_min = MAX (increment_min, pw_min);
-      increment_max = MIN (increment_max, pw_max);
-    }
-
     for (u32 increment_len = increment_min; increment_len <= increment_max; increment_len++)
     {
       char *mask_truncated = (char *) hcmalloc (256);
 
-      char *mask_truncated_next = mask_truncated;
+      const int rc_truncated_mask = mp_get_truncated_mask (hashcat_ctx, mask, strlen (mask), increment_len, mask_truncated);
 
-      if (prepend)
-      {
-        // this happens with maskfiles only
-
-        mask_truncated_next += snprintf (mask_truncated, 256, "%s,", prepend);
-      }
-
-      const int rc_truncated_mask = mp_get_truncated_mask (hashcat_ctx, mask, strlen (mask), increment_len, mask_truncated_next);
-
-      if (rc_truncated_mask == -1)
-      {
-        hcfree (mask_truncated);
-
-        break;
-      }
+      if (rc_truncated_mask == -1) break;
 
       const int rc = mask_append_final (hashcat_ctx, mask_truncated);
 
-      hcfree (mask_truncated);
-
       if (rc == -1) return -1;
     }
   }
   else
   {
-    if (prepend)
-    {
-      // this happens with maskfiles only
+    const int rc = mask_append_final (hashcat_ctx, mask);
 
-      char *prepend_mask;
-
-      hc_asprintf (&prepend_mask, "%s,%s", prepend, mask);
-
-      const int rc = mask_append_final (hashcat_ctx, prepend_mask);
-
-      hcfree (prepend_mask);
-
-      if (rc == -1) return -1;
-    }
-    else
-    {
-      const int rc = mask_append_final (hashcat_ctx, mask);
-
-      if (rc == -1) return -1;
-    }
+    if (rc == -1) return -1;
   }
 
   return 0;
@@ -1052,34 +985,6 @@ u32 mp_get_length (const char *mask)
   return len;
 }
 
-static char *mask_ctx_parse_maskfile_find_mask (char *line_buf, int line_len)
-{
-  char *mask_buf = line_buf;
-
-  bool escaped = false;
-
-  for (int i = 0; i < line_len; i++)
-  {
-    if (escaped == true)
-    {
-      escaped = false;
-    }
-    else
-    {
-      if (line_buf[i] == '\\')
-      {
-        escaped = true;
-      }
-      else if (line_buf[i] == ',')
-      {
-        mask_buf = line_buf + i + 1;
-      }
-    }
-  }
-
-  return mask_buf;
-}
-
 int mask_ctx_update_loop (hashcat_ctx_t *hashcat_ctx)
 {
   combinator_ctx_t     *combinator_ctx     = hashcat_ctx->combinator_ctx;
@@ -1117,14 +1022,7 @@ int mask_ctx_update_loop (hashcat_ctx_t *hashcat_ctx)
 
       sp_tbl_to_css (mask_ctx->root_table_buf, mask_ctx->markov_table_buf, mask_ctx->root_css_buf, mask_ctx->markov_css_buf, user_options->markov_threshold, uniq_tbls);
 
-      const int rc_get_sum = sp_get_sum (0, mask_ctx->css_cnt, mask_ctx->root_css_buf, &combinator_ctx->combs_cnt);
-
-      if (rc_get_sum == -1)
-      {
-        event_log_error (hashcat_ctx, "Integer overflow detected in keyspace of mask: %s", mask_ctx->mask);
-
-        return -1;
-      }
+      combinator_ctx->combs_cnt = sp_get_sum (0, mask_ctx->css_cnt, mask_ctx->root_css_buf);
 
       const int rc_update_mp = opencl_session_update_mp (hashcat_ctx);
 
@@ -1174,12 +1072,12 @@ int mask_ctx_update_loop (hashcat_ctx_t *hashcat_ctx)
       {
         if (mask_ctx->css_cnt < mask_min)
         {
-          event_log_warning (hashcat_ctx, "Skipping mask '%s' because it is smaller than the minimum password length.", mask_ctx->mask);
+          event_log_warning (hashcat_ctx, "Skipping mask '%s' because it is smaller than the minimum password length", mask_ctx->mask);
         }
 
         if (mask_ctx->css_cnt > mask_max)
         {
-          event_log_warning (hashcat_ctx, "Skipping mask '%s' because it is larger than the maximum password length.", mask_ctx->mask);
+          event_log_warning (hashcat_ctx, "Skipping mask '%s' because it is larger than the maximum password length", mask_ctx->mask);
         }
 
         // skip to next mask
@@ -1189,15 +1087,9 @@ int mask_ctx_update_loop (hashcat_ctx_t *hashcat_ctx)
         return 0;
       }
 
-      if (hashconfig->opts_type & OPTS_TYPE_PT_UTF16LE)
+      if (hashconfig->opts_type & OPTS_TYPE_PT_UNICODE)
       {
-        const int rc = mp_css_utf16le_expand (hashcat_ctx);
-
-        if (rc == -1) return -1;
-      }
-      else if (hashconfig->opts_type & OPTS_TYPE_PT_UTF16BE)
-      {
-        const int rc = mp_css_utf16be_expand (hashcat_ctx);
+        const int rc = mp_css_unicode_expand (hashcat_ctx);
 
         if (rc == -1) return -1;
       }
@@ -1220,14 +1112,7 @@ int mask_ctx_update_loop (hashcat_ctx_t *hashcat_ctx)
 
       sp_tbl_to_css (mask_ctx->root_table_buf, mask_ctx->markov_table_buf, mask_ctx->root_css_buf, mask_ctx->markov_css_buf, user_options->markov_threshold, uniq_tbls);
 
-      const int rc_get_sum1 = sp_get_sum (0, mask_ctx->css_cnt, mask_ctx->root_css_buf, &status_ctx->words_cnt);
-
-      if (rc_get_sum1 == -1)
-      {
-        event_log_error (hashcat_ctx, "Integer overflow detected in keyspace of mask: %s", mask_ctx->mask);
-
-        return -1;
-      }
+      status_ctx->words_cnt = sp_get_sum (0, mask_ctx->css_cnt, mask_ctx->root_css_buf);
 
       // copy + args
 
@@ -1235,14 +1120,7 @@ int mask_ctx_update_loop (hashcat_ctx_t *hashcat_ctx)
 
       mp_css_split_cnt (hashcat_ctx, css_cnt_orig, css_cnt_lr);
 
-      const int rc_get_sum2 = sp_get_sum (0, css_cnt_lr[1], mask_ctx->root_css_buf, &mask_ctx->bfs_cnt);
-
-      if (rc_get_sum2 == -1)
-      {
-        event_log_error (hashcat_ctx, "Integer overflow detected in keyspace of mask: %s", mask_ctx->mask);
-
-        return -1;
-      }
+      mask_ctx->bfs_cnt = sp_get_sum (0, css_cnt_lr[1], mask_ctx->root_css_buf);
 
       const int rc_update_mp_rl = opencl_session_update_mp_rl (hashcat_ctx, css_cnt_lr[0], css_cnt_lr[1]);
 
@@ -1306,9 +1184,11 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
       {
         char *arg = user_options_extra->hc_workv[0];
 
-        if (hc_path_exist (arg) == false)
+        hc_stat_t file_stat;
+
+        if (hc_stat (arg, &file_stat) == -1)
         {
-          const int rc = mask_append (hashcat_ctx, arg, NULL);
+          const int rc = mask_append (hashcat_ctx, arg);
 
           if (rc == -1) return -1;
         }
@@ -1320,7 +1200,14 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
           {
             arg = user_options_extra->hc_workv[i];
 
-            if (hc_path_is_file (arg) == true)
+            if (hc_stat (arg, &file_stat) == -1)
+            {
+              event_log_error (hashcat_ctx, "%s: %s", arg, strerror (errno));
+
+              return -1;
+            }
+
+            if (S_ISREG (file_stat.st_mode))
             {
               FILE *mask_fp = fopen (arg, "r");
 
@@ -1341,20 +1228,7 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
 
                 if (line_buf[0] == '#') continue;
 
-                char *mask_buf = mask_ctx_parse_maskfile_find_mask (line_buf, line_len);
-
-                char *prepend_buf = NULL;
-
-                if (line_buf != mask_buf)
-                {
-                  // if we have custom charsets
-
-                  prepend_buf = line_buf;
-
-                  mask_buf[-1] = 0;
-                }
-
-                const int rc = mask_append (hashcat_ctx, mask_buf, prepend_buf);
+                const int rc = mask_append (hashcat_ctx, line_buf);
 
                 if (rc == -1)
                 {
@@ -1370,7 +1244,7 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
             }
             else
             {
-              event_log_error (hashcat_ctx, "%s: unsupported file type.", arg);
+              event_log_error (hashcat_ctx, "%s: unsupported file-type", arg);
 
               return -1;
             }
@@ -1381,7 +1255,7 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
       {
         const char *mask = DEF_MASK;
 
-        const int rc = mask_append (hashcat_ctx, mask, NULL);
+        const int rc = mask_append (hashcat_ctx, mask);
 
         if (rc == -1) return -1;
       }
@@ -1390,7 +1264,7 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
     {
       const char *mask = hashconfig_benchmark_mask (hashcat_ctx);
 
-      const int rc = mask_append (hashcat_ctx, mask, NULL);
+      const int rc = mask_append (hashcat_ctx, mask);
 
       if (rc == -1) return -1;
     }
@@ -1403,15 +1277,17 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
 
     // mod
 
-    if (hc_path_exist (arg) == false)
+    hc_stat_t file_stat;
+
+    if (hc_stat (arg, &file_stat) == -1)
     {
-      const int rc = mask_append (hashcat_ctx, arg, NULL);
+      const int rc = mask_append (hashcat_ctx, arg);
 
       if (rc == -1) return -1;
     }
     else
     {
-      if (hc_path_is_file (arg) == true)
+      if (S_ISREG (file_stat.st_mode))
       {
         mask_ctx->mask_from_file = true;
 
@@ -1434,20 +1310,7 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
 
           if (line_buf[0] == '#') continue;
 
-          char *mask_buf = mask_ctx_parse_maskfile_find_mask (line_buf, line_len);
-
-          char *prepend_buf = NULL;
-
-          if (line_buf != mask_buf)
-          {
-            // if we have custom charsets
-
-            prepend_buf = line_buf;
-
-            mask_buf[-1] = 0;
-          }
-
-          const int rc = mask_append (hashcat_ctx, mask_buf, prepend_buf);
+          const int rc = mask_append (hashcat_ctx, line_buf);
 
           if (rc == -1)
           {
@@ -1463,7 +1326,7 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
       }
       else
       {
-        event_log_error (hashcat_ctx, "%s: unsupported file type.", arg);
+        event_log_error (hashcat_ctx, "%s: unsupported file-type", arg);
 
         return -1;
       }
@@ -1477,15 +1340,17 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
 
     // mod
 
-    if (hc_path_exist (arg) == false)
+    hc_stat_t file_stat;
+
+    if (hc_stat (arg, &file_stat) == -1)
     {
-      const int rc = mask_append (hashcat_ctx, arg, NULL);
+      const int rc = mask_append (hashcat_ctx, arg);
 
       if (rc == -1) return -1;
     }
     else
     {
-      if (hc_path_is_file (arg) == true)
+      if (S_ISREG (file_stat.st_mode))
       {
         mask_ctx->mask_from_file = true;
 
@@ -1508,20 +1373,7 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
 
           if (line_buf[0] == '#') continue;
 
-          char *mask_buf = mask_ctx_parse_maskfile_find_mask (line_buf, line_len);
-
-          char *prepend_buf = NULL;
-
-          if (line_buf != mask_buf)
-          {
-            // if we have custom charsets
-
-            prepend_buf = line_buf;
-
-            mask_buf[-1] = 0;
-          }
-
-          const int rc = mask_append (hashcat_ctx, mask_buf, prepend_buf);
+          const int rc = mask_append (hashcat_ctx, line_buf);
 
           if (rc == -1)
           {
@@ -1537,7 +1389,7 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
       }
       else
       {
-        event_log_error (hashcat_ctx, "%s: unsupported file type.", arg);
+        event_log_error (hashcat_ctx, "%s: unsupported file-type", arg);
 
         return -1;
       }
@@ -1546,7 +1398,7 @@ int mask_ctx_init (hashcat_ctx_t *hashcat_ctx)
 
   if (mask_ctx->masks_cnt == 0)
   {
-    event_log_error (hashcat_ctx, "Invalid mask.");
+    event_log_error (hashcat_ctx, "Invalid mask");
 
     return -1;
   }
@@ -1591,15 +1443,13 @@ int mask_ctx_parse_maskfile (hashcat_ctx_t *hashcat_ctx)
 
   if (mask_ctx->mask_from_file == false) return 0;
 
-  mf_t *mfs_buf = mask_ctx->mfs;
+  mf_t *mfs = mask_ctx->mfs;
 
-  mfs_buf[0].mf_len = 0;
-  mfs_buf[1].mf_len = 0;
-  mfs_buf[2].mf_len = 0;
-  mfs_buf[3].mf_len = 0;
-  mfs_buf[4].mf_len = 0;
-
-  int mfs_cnt = 0;
+  mfs[0].mf_len = 0;
+  mfs[1].mf_len = 0;
+  mfs[2].mf_len = 0;
+  mfs[3].mf_len = 0;
+  mfs[4].mf_len = 0;
 
   char *mask_buf = mask_ctx->mask;
 
@@ -1607,9 +1457,11 @@ int mask_ctx_parse_maskfile (hashcat_ctx_t *hashcat_ctx)
 
   bool escaped = false;
 
+  int mf_cnt = 0;
+
   for (int i = 0; i < mask_len; i++)
   {
-    mf_t *mf = mfs_buf + mfs_cnt;
+    mf_t *mf = mfs + mf_cnt;
 
     if (escaped == true)
     {
@@ -1629,11 +1481,11 @@ int mask_ctx_parse_maskfile (hashcat_ctx_t *hashcat_ctx)
       {
         mf->mf_buf[mf->mf_len] = 0;
 
-        mfs_cnt++;
+        mf_cnt++;
 
-        if (mfs_cnt == MAX_MFS)
+        if (mf_cnt >= MAX_MFS)
         {
-          event_log_error (hashcat_ctx, "Invalid line '%s' in maskfile.", mask_buf);
+          event_log_error (hashcat_ctx, "Invalid line '%s' in maskfile", mask_buf);
 
           return -1;
         }
@@ -1647,47 +1499,41 @@ int mask_ctx_parse_maskfile (hashcat_ctx_t *hashcat_ctx)
     }
   }
 
-  mf_t *mf = mfs_buf + mfs_cnt;
+  mf_t *mf = mfs + mf_cnt;
 
   mf->mf_buf[mf->mf_len] = 0;
 
-  user_options->custom_charset_1 = NULL;
-  user_options->custom_charset_2 = NULL;
-  user_options->custom_charset_3 = NULL;
-  user_options->custom_charset_4 = NULL;
-
-  mp_reset_usr (mask_ctx->mp_usr, 0);
-  mp_reset_usr (mask_ctx->mp_usr, 1);
-  mp_reset_usr (mask_ctx->mp_usr, 2);
-  mp_reset_usr (mask_ctx->mp_usr, 3);
-
-  for (int i = 0; i < mfs_cnt; i++)
+  for (int i = 0; i < mf_cnt; i++)
   {
     switch (i)
     {
       case 0:
-        user_options->custom_charset_1 = mfs_buf[0].mf_buf;
+        user_options->custom_charset_1 = mfs[0].mf_buf;
+        mp_reset_usr (mask_ctx->mp_usr, 0);
         mp_setup_usr (hashcat_ctx, mask_ctx->mp_sys, mask_ctx->mp_usr, user_options->custom_charset_1, 0);
         break;
 
       case 1:
-        user_options->custom_charset_2 = mfs_buf[1].mf_buf;
+        user_options->custom_charset_2 = mfs[1].mf_buf;
+        mp_reset_usr (mask_ctx->mp_usr, 1);
         mp_setup_usr (hashcat_ctx, mask_ctx->mp_sys, mask_ctx->mp_usr, user_options->custom_charset_2, 1);
         break;
 
       case 2:
-        user_options->custom_charset_3 = mfs_buf[2].mf_buf;
+        user_options->custom_charset_3 = mfs[2].mf_buf;
+        mp_reset_usr (mask_ctx->mp_usr, 2);
         mp_setup_usr (hashcat_ctx, mask_ctx->mp_sys, mask_ctx->mp_usr, user_options->custom_charset_3, 2);
         break;
 
       case 3:
-        user_options->custom_charset_4 = mfs_buf[3].mf_buf;
+        user_options->custom_charset_4 = mfs[3].mf_buf;
+        mp_reset_usr (mask_ctx->mp_usr, 3);
         mp_setup_usr (hashcat_ctx, mask_ctx->mp_sys, mask_ctx->mp_usr, user_options->custom_charset_4, 3);
         break;
     }
   }
 
-  mask_ctx->mask = mfs_buf[mfs_cnt].mf_buf;
+  mask_ctx->mask = mfs[mf_cnt].mf_buf;
 
   return 0;
 }
