@@ -30,6 +30,8 @@ static const char grp_op_nop[] =
   RULE_OP_MANGLE_SWITCH_LAST,
   RULE_OP_MANGLE_DUPECHAR_ALL,
   RULE_OP_MANGLE_TITLE,
+  RULE_OP_MANGLE_APPEND_MEMORY,
+  RULE_OP_MANGLE_PREPEND_MEMORY,
 };
 
 static const char grp_op_pos_p0[] =
@@ -58,8 +60,7 @@ static const char grp_op_chr[] =
 {
   RULE_OP_MANGLE_APPEND,
   RULE_OP_MANGLE_PREPEND,
-  RULE_OP_MANGLE_PURGECHAR,
-  RULE_OP_MANGLE_TITLE_SEP
+  RULE_OP_MANGLE_PURGECHAR
 };
 
 static const char grp_op_chr_chr[] =
@@ -84,6 +85,11 @@ static const char grp_op_pos_pos1[] =
   RULE_OP_MANGLE_OMIT
 };
 
+static const char grp_op_pos1_pos2_pos3[] =
+{
+  RULE_OP_MANGLE_EXTRACT_MEMORY
+};
+
 static const char grp_pos[] =
 {
   '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B'
@@ -150,6 +156,7 @@ int generate_random_rule (char rule_buf[RP_RULE_BUFSIZ], const u32 rp_gen_func_m
     u32 r  = 0;
     u32 p1 = 0;
     u32 p2 = 0;
+    u32 p3 = 0;
 
     switch ((char) get_random_num (0, 9))
     {
@@ -220,6 +227,17 @@ int generate_random_rule (char rule_buf[RP_RULE_BUFSIZ], const u32 rp_gen_func_m
         p2 = get_random_num (1, sizeof (grp_pos));
         rule_buf[rule_pos++] = grp_pos[p2];
         break;
+
+      case 8:
+        r = get_random_num (0, sizeof (grp_op_pos1_pos2_pos3));
+        rule_buf[rule_pos++] = grp_op_pos1_pos2_pos3[r];
+        p1 = get_random_num (0, sizeof (grp_pos));
+        rule_buf[rule_pos++] = grp_pos[p1];
+        p2 = get_random_num (1, sizeof (grp_pos));
+        rule_buf[rule_pos++] = grp_pos[p2];
+        p3 = get_random_num (0, sizeof (grp_pos));
+        rule_buf[rule_pos++] = grp_pos[p3];
+        break;
     }
   }
 
@@ -445,11 +463,6 @@ int cpu_rule_to_kernel_rule (char *rule_buf, u32 rule_len, kernel_rule_t *rule)
         SET_NAME (rule, rule_buf[rule_pos]);
         break;
 
-      case RULE_OP_MANGLE_TITLE_SEP:
-        SET_NAME (rule, rule_buf[rule_pos]);
-        SET_P0   (rule, rule_buf[rule_pos]);
-        break;
-
       default:
         return -1;
     }
@@ -668,13 +681,7 @@ int kernel_rule_to_cpu_rule (char *rule_buf, kernel_rule_t *rule)
         rule_buf[rule_pos] = rule_cmd;
         break;
 
-      case RULE_OP_MANGLE_TITLE_SEP:
-        rule_buf[rule_pos] = rule_cmd;
-        GET_P0 (rule);
-        break;
-
       case 0:
-        if (rule_pos == 0) return -1;
         return rule_pos - 1;
 
       default:
@@ -682,7 +689,12 @@ int kernel_rule_to_cpu_rule (char *rule_buf, kernel_rule_t *rule)
     }
   }
 
-  return rule_pos;
+  if (rule_cnt > 0)
+  {
+    return rule_pos;
+  }
+
+  return -1;
 }
 
 bool kernel_rules_has_noop (const kernel_rule_t *kernel_rules_buf, const u32 kernel_rules_cnt)
@@ -742,11 +754,6 @@ int kernel_rules_load (hashcat_ctx_t *hashcat_ctx, kernel_rule_t **out_buf, u32
     {
       event_log_error (hashcat_ctx, "%s: %s", rp_file, strerror (errno));
 
-      hcfree (all_kernel_rules_cnt);
-      hcfree (all_kernel_rules_buf);
-
-      hcfree (rule_buf);
-
       return -1;
     }
 
@@ -835,7 +842,7 @@ int kernel_rules_load (hashcat_ctx_t *hashcat_ctx, kernel_rule_t **out_buf, u32
       {
         if (out_pos == RULES_MAX - 1)
         {
-          // event_log_warning (hashcat_ctx, "Truncated chaining of rule %d and rule %d - maximum functions per rule exceeded.", i, in_off);
+          // event_log_warning (hashcat_ctx, "Truncating chaining of rule %d and rule %d as maximum number of function calls per rule exceeded", i, in_off);
 
           break;
         }
@@ -847,18 +854,16 @@ int kernel_rules_load (hashcat_ctx_t *hashcat_ctx, kernel_rule_t **out_buf, u32
 
   hcfree (repeats);
 
-  hcfree (all_kernel_rules_cnt);
-  hcfree (all_kernel_rules_buf);
-
   if (kernel_rules_cnt == 0)
   {
-    event_log_error (hashcat_ctx, "No valid rules left.");
-
-    hcfree (kernel_rules_buf);
+    event_log_error (hashcat_ctx, "No valid rules left");
 
     return -1;
   }
 
+  hcfree (all_kernel_rules_cnt);
+  hcfree (all_kernel_rules_buf);
+
   *out_cnt = kernel_rules_cnt;
   *out_buf = kernel_rules_buf;
 
@@ -889,4 +894,4 @@ int kernel_rules_generate (hashcat_ctx_t *hashcat_ctx, kernel_rule_t **out_buf,
   *out_buf = kernel_rules_buf;
 
   return 0;
-}
+}
\ No newline at end of file
