@@ -27,19 +27,19 @@ static void out_push (out_t *out, const u8 *pw_buf, const int pw_len)
 
   memcpy (ptr, pw_buf, pw_len);
 
-  #if defined (_WIN)
+  #if defined (_POSIX)
+
+  ptr[pw_len] = '\n';
+
+  out->len += pw_len + 1;
+
+  #else
 
   ptr[pw_len + 0] = '\r';
   ptr[pw_len + 1] = '\n';
 
   out->len += pw_len + 2;
 
-  #else
-
-  ptr[pw_len] = '\n';
-
-  out->len += pw_len + 1;
-
   #endif
 
   if (out->len >= BUFSIZ - 100)
