@@ -19,8 +19,6 @@
 #include "terminal.h"
 #include "hashcat.h"
 
-static const size_t TERMINAL_LINE_LENGTH = 79;
-
 static const char *PROMPT = "[s]tatus [p]ause [r]esume [b]ypass [c]heckpoint [q]uit => ";
 
 void welcome_screen (hashcat_ctx_t *hashcat_ctx, const char *version_tag)
@@ -38,7 +36,7 @@ void welcome_screen (hashcat_ctx_t *hashcat_ctx, const char *version_tag)
     if (user_options->machine_readable == false)
     {
       event_log_info (hashcat_ctx, "%s (%s) starting in benchmark mode...", PROGNAME, version_tag);
-      event_log_info (hashcat_ctx, NULL);
+      event_log_info (hashcat_ctx, "");
     }
     else
     {
@@ -48,22 +46,17 @@ void welcome_screen (hashcat_ctx_t *hashcat_ctx, const char *version_tag)
   else if (user_options->restore == true)
   {
     event_log_info (hashcat_ctx, "%s (%s) starting in restore mode...", PROGNAME, version_tag);
-    event_log_info (hashcat_ctx, NULL);
+    event_log_info (hashcat_ctx, "");
   }
   else if (user_options->speed_only == true)
   {
     event_log_info (hashcat_ctx, "%s (%s) starting in speed-only mode...", PROGNAME, version_tag);
-    event_log_info (hashcat_ctx, NULL);
-  }
-  else if (user_options->progress_only == true)
-  {
-    event_log_info (hashcat_ctx, "%s (%s) starting in progress-only mode...", PROGNAME, version_tag);
-    event_log_info (hashcat_ctx, NULL);
+    event_log_info (hashcat_ctx, "");
   }
   else
   {
     event_log_info (hashcat_ctx, "%s (%s) starting...", PROGNAME, version_tag);
-    event_log_info (hashcat_ctx, NULL);
+    event_log_info (hashcat_ctx, "");
   }
 }
 
@@ -77,11 +70,8 @@ void goodbye_screen (hashcat_ctx_t *hashcat_ctx, const time_t proc_start, const
   if (user_options->show        == true) return;
   if (user_options->left        == true) return;
 
-  char start_buf[32]; memset (start_buf, 0, sizeof (start_buf));
-  char stop_buf[32];  memset (start_buf, 0, sizeof (stop_buf));
-
-  event_log_info_nn (hashcat_ctx, "Started: %s", ctime_r (&proc_start, start_buf));
-  event_log_info_nn (hashcat_ctx, "Stopped: %s", ctime_r (&proc_stop,  stop_buf));
+  event_log_info_nn (hashcat_ctx, "Started: %s", ctime (&proc_start));
+  event_log_info_nn (hashcat_ctx, "Stopped: %s", ctime (&proc_stop));
 }
 
 int setup_console ()
@@ -91,21 +81,21 @@ int setup_console ()
 
   if (_setmode (_fileno (stdin), _O_BINARY) == -1)
   {
-    __mingw_fprintf (stderr, "%s: %m", "stdin");
+    fprintf (stderr, "%s: %s", "stdin", strerror (errno));
 
     return -1;
   }
 
   if (_setmode (_fileno (stdout), _O_BINARY) == -1)
   {
-    __mingw_fprintf (stderr, "%s: %m", "stdin");
+    fprintf (stderr, "%s: %s", "stdin", strerror (errno));
 
     return -1;
   }
 
   if (_setmode (_fileno (stderr), _O_BINARY) == -1)
   {
-    __mingw_fprintf (stderr, "%s: %m", "stdin");
+    fprintf (stderr, "%s: %s", "stdin", strerror (errno));
 
     return -1;
   }
@@ -162,7 +152,7 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
 
     hc_thread_mutex_lock (status_ctx->mux_display);
 
-    event_log_info (hashcat_ctx, NULL);
+    event_log_info (hashcat_ctx, "");
 
     switch (ch)
     {
@@ -170,11 +160,11 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
       case '\r':
       case '\n':
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         status_display (hashcat_ctx);
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         if (quiet == false) send_prompt ();
 
@@ -182,13 +172,13 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
 
       case 'b':
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         bypass (hashcat_ctx);
 
-        event_log_info (hashcat_ctx, "Next dictionary / mask in queue selected. Bypassing current one.");
+        event_log_info (hashcat_ctx, "Next dictionary / mask in queue selected, bypassing current one");
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         if (quiet == false) send_prompt ();
 
@@ -196,7 +186,7 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
 
       case 'p':
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         SuspendThreads (hashcat_ctx);
 
@@ -205,7 +195,7 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
           event_log_info (hashcat_ctx, "Paused");
         }
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         if (quiet == false) send_prompt ();
 
@@ -213,7 +203,7 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
 
       case 'r':
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         ResumeThreads (hashcat_ctx);
 
@@ -222,7 +212,7 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
           event_log_info (hashcat_ctx, "Resumed");
         }
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         if (quiet == false) send_prompt ();
 
@@ -230,20 +220,20 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
 
       case 'c':
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         stop_at_checkpoint (hashcat_ctx);
 
         if (status_ctx->checkpoint_shutdown == true)
         {
-          event_log_info (hashcat_ctx, "Checkpoint enabled. Will quit at next restore-point update.");
+          event_log_info (hashcat_ctx, "Checkpoint enabled: Will quit at next Restore Point update");
         }
         else
         {
-          event_log_info (hashcat_ctx, "Checkpoint disabled. Restore-point updates will no longer be monitored.");
+          event_log_info (hashcat_ctx, "Checkpoint disabled: Restore Point updates will no longer be monitored");
         }
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         if (quiet == false) send_prompt ();
 
@@ -251,7 +241,7 @@ static void keypress (hashcat_ctx_t *hashcat_ctx)
 
       case 'q':
 
-        event_log_info (hashcat_ctx, NULL);
+        event_log_info (hashcat_ctx, "");
 
         myquit (hashcat_ctx);
 
@@ -353,7 +343,7 @@ int tty_fix()
 }
 #endif
 
-#if defined (__APPLE__) || defined (__FreeBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__)
 static struct termios savemodes;
 static int havemodes = 0;
 
@@ -465,35 +455,12 @@ int tty_fix()
 }
 #endif
 
-void compress_terminal_line_length (char *out_buf, const size_t keep_from_beginning, const size_t keep_from_end)
-{
-  const size_t target_len = TERMINAL_LINE_LENGTH - keep_from_beginning;
-
-  const size_t out_len = strlen (out_buf);
-
-  if (out_len < target_len) return;
-
-  char *ptr1 = out_buf + target_len - 3 - keep_from_end;
-  char *ptr2 = out_buf + out_len - keep_from_end;
-
-  *ptr1++ = '.';
-  *ptr1++ = '.';
-  *ptr1++ = '.';
-
-  for (size_t i = 0; i < keep_from_end; i++)
-  {
-    *ptr1++ = *ptr2++;
-  }
-
-  *ptr1 = 0;
-}
-
 void opencl_info (hashcat_ctx_t *hashcat_ctx)
 {
   const opencl_ctx_t *opencl_ctx = hashcat_ctx->opencl_ctx;
 
   event_log_info (hashcat_ctx, "OpenCL Info:");
-  event_log_info (hashcat_ctx, NULL);
+  event_log_info (hashcat_ctx, "");
 
   cl_uint         platforms_cnt         = opencl_ctx->platforms_cnt;
   cl_platform_id *platforms             = opencl_ctx->platforms;
@@ -513,7 +480,7 @@ void opencl_info (hashcat_ctx_t *hashcat_ctx)
     event_log_info (hashcat_ctx, "  Vendor  : %s",  platform_vendor);
     event_log_info (hashcat_ctx, "  Name    : %s",  platform_name);
     event_log_info (hashcat_ctx, "  Version : %s",  platform_version);
-    event_log_info (hashcat_ctx, NULL);
+    event_log_info (hashcat_ctx, "");
 
     for (cl_uint devices_idx = 0; devices_idx < devices_cnt; devices_idx++)
     {
@@ -544,7 +511,7 @@ void opencl_info (hashcat_ctx_t *hashcat_ctx)
       event_log_info (hashcat_ctx, "    Memory         : %" PRIu64 "/%" PRIu64 " MB allocatable", device_maxmem_alloc / 1024 / 1024, device_global_mem / 1024 / 1024);
       event_log_info (hashcat_ctx, "    OpenCL Version : %s", device_opencl_version);
       event_log_info (hashcat_ctx, "    Driver Version : %s", driver_version);
-      event_log_info (hashcat_ctx, NULL);
+      event_log_info (hashcat_ctx, "");
     }
   }
 }
@@ -583,7 +550,7 @@ void opencl_info_compact (hashcat_ctx_t *hashcat_ctx)
     }
     else
     {
-      event_log_info (hashcat_ctx, "OpenCL Platform #%u: %s, skipped or no OpenCL compatible devices found.", platforms_idx + 1, platform_vendor);
+      event_log_info (hashcat_ctx, "OpenCL Platform #%u: %s, skipped or no OpenCL compatible devices found", platforms_idx + 1, platform_vendor);
     }
 
     for (cl_uint devices_idx = 0; devices_idx < devices_cnt; devices_idx++)
@@ -608,13 +575,13 @@ void opencl_info_compact (hashcat_ctx_t *hashcat_ctx)
       }
       else
       {
-        event_log_info (hashcat_ctx, "* Device #%u: %s, skipped.",
+        event_log_info (hashcat_ctx, "* Device #%u: %s, skipped",
                   devices_idx + 1,
                   device_name);
       }
     }
 
-    event_log_info (hashcat_ctx, NULL);
+    event_log_info (hashcat_ctx, "");
   }
 }
 
@@ -686,14 +653,10 @@ void status_display_machine_readable (hashcat_ctx_t *hashcat_ctx)
     }
   }
 
-  printf ("REJECTED\t%" PRIu64 "\t", hashcat_status->progress_rejected);
-
   fwrite (EOL, strlen (EOL), 1, stdout);
 
   fflush (stdout);
 
-  status_status_destroy (hashcat_ctx, hashcat_status);
-
   hcfree (hashcat_status);
 }
 
@@ -749,255 +712,225 @@ void status_display (hashcat_ctx_t *hashcat_ctx)
     hashcat_status->time_estimated_absolute,
     hashcat_status->time_estimated_relative);
 
-  switch (hashcat_status->guess_mode)
+  switch (hashcat_status->input_mode)
   {
-    case GUESS_MODE_STRAIGHT_FILE:
+    case INPUT_MODE_STRAIGHT_FILE:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: File (%s)",
-        hashcat_status->guess_base);
+        "Input.Base.......: File (%s)",
+        hashcat_status->input_base);
 
       break;
 
-    case GUESS_MODE_STRAIGHT_FILE_RULES_FILE:
+    case INPUT_MODE_STRAIGHT_FILE_RULES_FILE:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: File (%s)",
-        hashcat_status->guess_base);
+        "Input.Base.......: File (%s)",
+        hashcat_status->input_base);
 
       event_log_info (hashcat_ctx,
-        "Guess.Mod........: Rules (%s)",
-        hashcat_status->guess_mod);
+        "Input.Mod........: Rules (%s)",
+        hashcat_status->input_mod);
 
       break;
 
-    case GUESS_MODE_STRAIGHT_FILE_RULES_GEN:
+    case INPUT_MODE_STRAIGHT_FILE_RULES_GEN:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: File (%s)",
-        hashcat_status->guess_base);
+        "Input.Base.......: File (%s)",
+        hashcat_status->input_base);
 
       event_log_info (hashcat_ctx,
-        "Guess.Mod........: Rules (Generated)");
+        "Input.Mod........: Rules (Generated)");
 
       break;
 
-    case GUESS_MODE_STRAIGHT_STDIN:
+    case INPUT_MODE_STRAIGHT_STDIN:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: Pipe");
+        "Input.Base.......: Pipe");
 
       break;
 
-    case GUESS_MODE_STRAIGHT_STDIN_RULES_FILE:
+    case INPUT_MODE_STRAIGHT_STDIN_RULES_FILE:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: Pipe");
+        "Input.Base.......: Pipe");
 
       event_log_info (hashcat_ctx,
-        "Guess.Mod........: Rules (%s)",
-        hashcat_status->guess_mod);
+        "Input.Mod........: Rules (%s)",
+        hashcat_status->input_mod);
 
       break;
 
-    case GUESS_MODE_STRAIGHT_STDIN_RULES_GEN:
+    case INPUT_MODE_STRAIGHT_STDIN_RULES_GEN:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: Pipe");
+        "Input.Base.......: Pipe");
 
       event_log_info (hashcat_ctx,
-        "Guess.Mod........: Rules (Generated)");
+        "Input.Mod........: Rules (Generated)");
 
       break;
 
-    case GUESS_MODE_COMBINATOR_BASE_LEFT:
+    case INPUT_MODE_COMBINATOR_BASE_LEFT:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: File (%s), Left Side",
-        hashcat_status->guess_base);
+        "Input.Base.......: File (%s), Left Side",
+        hashcat_status->input_base);
 
       event_log_info (hashcat_ctx,
-        "Guess.Mod........: File (%s), Right Side",
-        hashcat_status->guess_mod);
+        "Input.Mod........: File (%s), Right Side",
+        hashcat_status->input_mod);
 
       break;
 
-    case GUESS_MODE_COMBINATOR_BASE_RIGHT:
+    case INPUT_MODE_COMBINATOR_BASE_RIGHT:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: File (%s), Right Side",
-        hashcat_status->guess_base);
+        "Input.Base.......: File (%s), Right Side",
+        hashcat_status->input_base);
 
       event_log_info (hashcat_ctx,
-        "Guess.Mod........: File (%s), Left Side",
-        hashcat_status->guess_mod);
+        "Input.Mod........: File (%s), Left Side",
+        hashcat_status->input_mod);
 
       break;
 
-    case GUESS_MODE_MASK:
+    case INPUT_MODE_MASK:
 
       event_log_info (hashcat_ctx,
-        "Guess.Mask.......: %s [%d]",
-        hashcat_status->guess_base,
-        hashcat_status->guess_mask_length);
+        "Input.Mask.......: %s [%d]",
+        hashcat_status->input_base,
+        hashcat_status->input_mask_length);
 
       break;
 
-    case GUESS_MODE_MASK_CS:
+    case INPUT_MODE_MASK_CS:
 
       event_log_info (hashcat_ctx,
-        "Guess.Mask.......: %s [%d]",
-        hashcat_status->guess_base,
-        hashcat_status->guess_mask_length);
+        "Input.Mask.......: %s [%d]",
+        hashcat_status->input_base,
+        hashcat_status->input_mask_length);
 
       event_log_info (hashcat_ctx,
-        "Guess.Charset....: %s ",
-        hashcat_status->guess_charset);
+        "Input.Charset....: %s ",
+        hashcat_status->input_charset);
 
       break;
 
-    case GUESS_MODE_HYBRID1:
+    case INPUT_MODE_HYBRID1:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: File (%s), Left Side",
-        hashcat_status->guess_base);
+        "Input.Base.......: File (%s), Left Side",
+        hashcat_status->input_base);
 
       event_log_info (hashcat_ctx,
-        "Guess.Mod........: Mask (%s) [%d], Right Side",
-        hashcat_status->guess_mod,
-        hashcat_status->guess_mask_length);
+        "Input.Mod........: Mask (%s) [%d], Right Side",
+        hashcat_status->input_mod,
+        hashcat_status->input_mask_length);
 
       break;
 
-    case GUESS_MODE_HYBRID1_CS:
+    case INPUT_MODE_HYBRID1_CS:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: File (%s), Left Side",
-        hashcat_status->guess_base);
+        "Input.Base.......: File (%s), Left Side",
+        hashcat_status->input_base);
 
       event_log_info (hashcat_ctx,
-        "Guess.Mod........: Mask (%s) [%d], Right Side",
-        hashcat_status->guess_mod,
-        hashcat_status->guess_mask_length);
+        "Input.Mod........: Mask (%s) [%d], Right Side",
+        hashcat_status->input_mod,
+        hashcat_status->input_mask_length);
 
       event_log_info (hashcat_ctx,
-        "Guess.Charset....: %s",
-        hashcat_status->guess_charset);
+        "Input.Charset....: %s",
+        hashcat_status->input_charset);
 
       break;
 
-    case GUESS_MODE_HYBRID2:
+    case INPUT_MODE_HYBRID2:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: File (%s), Right Side",
-        hashcat_status->guess_base);
+        "Input.Base.......: File (%s), Right Side",
+        hashcat_status->input_base);
 
       event_log_info (hashcat_ctx,
-        "Guess.Mod........: Mask (%s) [%d], Left Side",
-        hashcat_status->guess_mod,
-        hashcat_status->guess_mask_length);
+        "Input.Mod........: Mask (%s) [%d], Left Side",
+        hashcat_status->input_mod,
+        hashcat_status->input_mask_length);
 
       break;
 
-    case GUESS_MODE_HYBRID2_CS:
+    case INPUT_MODE_HYBRID2_CS:
 
       event_log_info (hashcat_ctx,
-        "Guess.Base.......: File (%s), Right Side",
-        hashcat_status->guess_base);
+        "Input.Base.......: File (%s), Right Side",
+        hashcat_status->input_base);
 
       event_log_info (hashcat_ctx,
-        "Guess.Mod........: Mask (%s) [%d], Left Side",
-        hashcat_status->guess_mod,
-        hashcat_status->guess_mask_length);
+        "Input.Mod........: Mask (%s) [%d], Left Side",
+        hashcat_status->input_mod,
+        hashcat_status->input_mask_length);
 
       event_log_info (hashcat_ctx,
-        "Guess.Charset....: %s",
-        hashcat_status->guess_charset);
+        "Input.Charset....: %s",
+        hashcat_status->input_charset);
 
       break;
   }
 
-  switch (hashcat_status->guess_mode)
+  switch (hashcat_status->input_mode)
   {
-    case GUESS_MODE_STRAIGHT_FILE:
+    case INPUT_MODE_STRAIGHT_FILE:
 
       event_log_info (hashcat_ctx,
-        "Guess.Queue......: %d/%d (%.02f%%)",
-        hashcat_status->guess_base_offset,
-        hashcat_status->guess_base_count,
-        hashcat_status->guess_base_percent);
+        "Input.Queue......: %d/%d (%.02f%%)",
+        hashcat_status->input_base_offset,
+        hashcat_status->input_base_count,
+        hashcat_status->input_base_percent);
 
       break;
 
-    case GUESS_MODE_STRAIGHT_FILE_RULES_FILE:
+    case INPUT_MODE_MASK:
 
       event_log_info (hashcat_ctx,
-        "Guess.Queue......: %d/%d (%.02f%%)",
-        hashcat_status->guess_base_offset,
-        hashcat_status->guess_base_count,
-        hashcat_status->guess_base_percent);
+        "Input.Queue......: %d/%d (%.02f%%)",
+        hashcat_status->input_base_offset,
+        hashcat_status->input_base_count,
+        hashcat_status->input_base_percent);
 
       break;
 
-    case GUESS_MODE_STRAIGHT_FILE_RULES_GEN:
+    case INPUT_MODE_HYBRID1:
 
       event_log_info (hashcat_ctx,
-        "Guess.Queue......: %d/%d (%.02f%%)",
-        hashcat_status->guess_base_offset,
-        hashcat_status->guess_base_count,
-        hashcat_status->guess_base_percent);
+        "Input.Queue.Base.: %d/%d (%.02f%%)",
+        hashcat_status->input_base_offset,
+        hashcat_status->input_base_count,
+        hashcat_status->input_base_percent);
+
+      event_log_info (hashcat_ctx,
+        "Input.Queue.Mod..: %d/%d (%.02f%%)",
+        hashcat_status->input_mod_offset,
+        hashcat_status->input_mod_count,
+        hashcat_status->input_mod_percent);
 
       break;
 
-    case GUESS_MODE_MASK:
+    case INPUT_MODE_HYBRID2:
 
       event_log_info (hashcat_ctx,
-        "Guess.Queue......: %d/%d (%.02f%%)",
-        hashcat_status->guess_base_offset,
-        hashcat_status->guess_base_count,
-        hashcat_status->guess_base_percent);
-
-      break;
-
-    case GUESS_MODE_MASK_CS:
+        "Input.Queue.Base.: %d/%d (%.02f%%)",
+        hashcat_status->input_base_offset,
+        hashcat_status->input_base_count,
+        hashcat_status->input_base_percent);
 
       event_log_info (hashcat_ctx,
-        "Guess.Queue......: %d/%d (%.02f%%)",
-        hashcat_status->guess_base_offset,
-        hashcat_status->guess_base_count,
-        hashcat_status->guess_base_percent);
-
-      break;
-
-    case GUESS_MODE_HYBRID1:
-
-      event_log_info (hashcat_ctx,
-        "Guess.Queue.Base.: %d/%d (%.02f%%)",
-        hashcat_status->guess_base_offset,
-        hashcat_status->guess_base_count,
-        hashcat_status->guess_base_percent);
-
-      event_log_info (hashcat_ctx,
-        "Guess.Queue.Mod..: %d/%d (%.02f%%)",
-        hashcat_status->guess_mod_offset,
-        hashcat_status->guess_mod_count,
-        hashcat_status->guess_mod_percent);
-
-      break;
-
-    case GUESS_MODE_HYBRID2:
-
-      event_log_info (hashcat_ctx,
-        "Guess.Queue.Base.: %d/%d (%.02f%%)",
-        hashcat_status->guess_base_offset,
-        hashcat_status->guess_base_count,
-        hashcat_status->guess_base_percent);
-
-      event_log_info (hashcat_ctx,
-        "Guess.Queue.Mod..: %d/%d (%.02f%%)",
-        hashcat_status->guess_mod_offset,
-        hashcat_status->guess_mod_count,
-        hashcat_status->guess_mod_percent);
+        "Input.Queue.Mod..: %d/%d (%.02f%%)",
+        hashcat_status->input_mod_offset,
+        hashcat_status->input_mod_count,
+        hashcat_status->input_mod_percent);
 
       break;
   }
@@ -1084,11 +1017,11 @@ void status_display (hashcat_ctx_t *hashcat_ctx)
 
     if (device_info->skipped_dev == true) continue;
 
-    if (device_info->guess_candidates_dev == NULL) continue;
+    if (device_info->input_candidates_dev == NULL) continue;
 
     event_log_info (hashcat_ctx,
       "Candidates.#%d....: %s", device_id + 1,
-      device_info->guess_candidates_dev);
+      device_info->input_candidates_dev);
   }
 
   if (user_options->gpu_temp_disable == false)
@@ -1107,12 +1040,10 @@ void status_display (hashcat_ctx_t *hashcat_ctx)
     }
   }
 
-  status_status_destroy (hashcat_ctx, hashcat_status);
-
   hcfree (hashcat_status);
 }
 
-void status_benchmark_machine_readable (hashcat_ctx_t *hashcat_ctx)
+void status_benchmark_automate (hashcat_ctx_t *hashcat_ctx)
 {
   hashconfig_t *hashconfig = hashcat_ctx->hashconfig;
 
@@ -1138,8 +1069,6 @@ void status_benchmark_machine_readable (hashcat_ctx_t *hashcat_ctx)
     event_log_info (hashcat_ctx, "%d:%u:%d:%d:%.2f:%" PRIu64, device_id + 1, hash_mode, device_info->corespeed_dev, device_info->memoryspeed_dev, device_info->exec_msec_dev, (u64) (device_info->hashes_msec_dev_benchmark * 1000));
   }
 
-  status_status_destroy (hashcat_ctx, hashcat_status);
-
   hcfree (hashcat_status);
 }
 
@@ -1149,7 +1078,7 @@ void status_benchmark (hashcat_ctx_t *hashcat_ctx)
 
   if (user_options->machine_readable == true)
   {
-    status_benchmark_machine_readable (hashcat_ctx);
+    status_benchmark_automate (hashcat_ctx);
 
     return;
   }
@@ -1184,156 +1113,5 @@ void status_benchmark (hashcat_ctx_t *hashcat_ctx)
       hashcat_status->speed_sec_all);
   }
 
-  status_status_destroy (hashcat_ctx, hashcat_status);
-
-  hcfree (hashcat_status);
-}
-
-void status_speed_machine_readable (hashcat_ctx_t *hashcat_ctx)
-{
-  hashcat_status_t *hashcat_status = (hashcat_status_t *) hcmalloc (sizeof (hashcat_status_t));
-
-  const int rc_status = hashcat_get_status (hashcat_ctx, hashcat_status);
-
-  if (rc_status == -1)
-  {
-    hcfree (hashcat_status);
-
-    return;
-  }
-
-  for (int device_id = 0; device_id < hashcat_status->device_info_cnt; device_id++)
-  {
-    const device_info_t *device_info = hashcat_status->device_info_buf + device_id;
-
-    if (device_info->skipped_dev == true) continue;
-
-    event_log_info (hashcat_ctx, "%d:%" PRIu64, device_id + 1, (u64) (device_info->hashes_msec_dev_benchmark * 1000));
-  }
-
-  status_status_destroy (hashcat_ctx, hashcat_status);
-
-  hcfree (hashcat_status);
-}
-
-void status_speed (hashcat_ctx_t *hashcat_ctx)
-{
-  const user_options_t *user_options = hashcat_ctx->user_options;
-
-  if (user_options->machine_readable == true)
-  {
-    status_speed_machine_readable (hashcat_ctx);
-
-    return;
-  }
-
-  hashcat_status_t *hashcat_status = (hashcat_status_t *) hcmalloc (sizeof (hashcat_status_t));
-
-  const int rc_status = hashcat_get_status (hashcat_ctx, hashcat_status);
-
-  if (rc_status == -1)
-  {
-    hcfree (hashcat_status);
-
-    return;
-  }
-
-  for (int device_id = 0; device_id < hashcat_status->device_info_cnt; device_id++)
-  {
-    const device_info_t *device_info = hashcat_status->device_info_buf + device_id;
-
-    if (device_info->skipped_dev == true) continue;
-
-    event_log_info (hashcat_ctx,
-      "Speed.Dev.#%d.....: %9sH/s (%0.2fms)", device_id + 1,
-      device_info->speed_sec_dev,
-      device_info->exec_msec_dev);
-  }
-
-  if (hashcat_status->device_info_active > 1)
-  {
-    event_log_info (hashcat_ctx,
-      "Speed.Dev.#*.....: %9sH/s",
-      hashcat_status->speed_sec_all);
-  }
-
-  status_status_destroy (hashcat_ctx, hashcat_status);
-
-  hcfree (hashcat_status);
-}
-
-void status_progress_machine_readable (hashcat_ctx_t *hashcat_ctx)
-{
-  hashcat_status_t *hashcat_status = (hashcat_status_t *) hcmalloc (sizeof (hashcat_status_t));
-
-  const int rc_status = hashcat_get_status (hashcat_ctx, hashcat_status);
-
-  if (rc_status == -1)
-  {
-    hcfree (hashcat_status);
-
-    return;
-  }
-
-  for (int device_id = 0; device_id < hashcat_status->device_info_cnt; device_id++)
-  {
-    const device_info_t *device_info = hashcat_status->device_info_buf + device_id;
-
-    if (device_info->skipped_dev == true) continue;
-
-    event_log_info (hashcat_ctx, "%d:%d:%0.2f", device_id + 1, device_info->progress_dev, device_info->runtime_msec_dev);
-  }
-
-  status_status_destroy (hashcat_ctx, hashcat_status);
-
-  hcfree (hashcat_status);
-}
-
-void status_progress (hashcat_ctx_t *hashcat_ctx)
-{
-  const user_options_t *user_options = hashcat_ctx->user_options;
-
-  if (user_options->machine_readable == true)
-  {
-    status_progress_machine_readable (hashcat_ctx);
-
-    return;
-  }
-
-  hashcat_status_t *hashcat_status = (hashcat_status_t *) hcmalloc (sizeof (hashcat_status_t));
-
-  const int rc_status = hashcat_get_status (hashcat_ctx, hashcat_status);
-
-  if (rc_status == -1)
-  {
-    hcfree (hashcat_status);
-
-    return;
-  }
-
-  for (int device_id = 0; device_id < hashcat_status->device_info_cnt; device_id++)
-  {
-    const device_info_t *device_info = hashcat_status->device_info_buf + device_id;
-
-    if (device_info->skipped_dev == true) continue;
-
-    event_log_info (hashcat_ctx,
-      "Progress.Dev.#%d..: %d", device_id + 1,
-      device_info->progress_dev);
-  }
-
-  for (int device_id = 0; device_id < hashcat_status->device_info_cnt; device_id++)
-  {
-    const device_info_t *device_info = hashcat_status->device_info_buf + device_id;
-
-    if (device_info->skipped_dev == true) continue;
-
-    event_log_info (hashcat_ctx,
-      "Runtime.Dev.#%d...: %0.2fms", device_id + 1,
-      device_info->runtime_msec_dev);
-  }
-
-  status_status_destroy (hashcat_ctx, hashcat_status);
-
   hcfree (hashcat_status);
 }
