@@ -1,16 +1,13 @@
 #!/usr/bin/env bash
 
 ##
-## Authors.....: Gabriele Gristina <matrix@hashcat.net>
-##               Jens Steube <jens.steube@gmail.com>
-##               magnum <john.magnum@hushmail.com>
-##
+## Author......: See docs/credits.txt
 ## License.....: MIT
 ##
 
 # missing hash types: 5200,6211,6221,6231,6241,6251,6261,6271,6281
 
-HASH_TYPES="0 10 11 12 20 21 22 23 30 40 50 60 100 101 110 111 112 120 121 122 125 130 131 132 133 140 141 150 160 200 300 400 500 900 1000 1100 1400 1410 1420 1430 1440 1441 1450 1460 1500 1600 1700 1710 1711 1720 1722 1730 1731 1740 1750 1760 1800 2100 2400 2410 2500 2600 2611 2612 2711 2811 3000 3100 3200 3710 3711 3800 4300 4400 4500 4700 4800 4900 5000 5100 5300 5400 5500 5600 5700 5800 6000 6100 6300 6400 6500 6600 6700 6800 6900 7100 7200 7300 7400 7500 7600 7700 7800 7900 8000 8100 8200 8300 8400 8500 8600 8700 8900 9100 9200 9300 9400 9500 9600 9700 9800 9900 10000 10100 10200 10300 10400 10500 10600 10700 10800 10900 11000 11100 11200 11300 11400 11500 11600 11900 12000 12100 12200 12300 12400 12600 12800 12900 13000 13100 13200 13300 13400 13500 13600 13800"
+HASH_TYPES="0 10 11 12 20 21 22 23 30 40 50 60 100 101 110 111 112 120 121 122 125 130 131 132 133 140 141 150 160 200 300 400 500 900 1000 1100 1400 1410 1420 1430 1440 1441 1450 1460 1500 1600 1700 1710 1711 1720 1722 1730 1731 1740 1750 1760 1800 2100 2400 2410 2500 2600 2611 2612 2711 2811 3000 3100 3200 3710 3711 3800 4300 4400 4500 4700 4800 4900 5000 5100 5300 5400 5500 5600 5700 5800 6000 6100 6300 6400 6500 6600 6700 6800 6900 7100 7200 7300 7400 7500 7600 7700 7800 7900 8000 8100 8200 8300 8400 8500 8600 8700 8900 9100 9200 9300 9400 9500 9600 9700 9800 9900 10000 10100 10200 10300 10400 10500 10600 10700 10800 10900 11000 11100 11200 11300 11400 11500 11600 11900 12000 12100 12200 12300 12400 12600 12800 12900 13000 13100 13200 13300 13400 13500 13600 13800 14000 14100 14400 99999"
 
 #ATTACK_MODES="0 1 3 6 7"
 ATTACK_MODES="0 1 3 7"
@@ -186,6 +183,18 @@ function init()
 
   fi
 
+  if [ "${hash_type}" -eq 14000 ]; then
+
+    min_len=7
+
+  fi
+
+  if [ "${hash_type}" -eq 14100 ]; then
+
+    min_len=23
+
+  fi
+
   while read -u 9 pass; do
 
     if [ ${i} -gt 1 ]; then
@@ -230,6 +239,18 @@ function init()
 
   fi
 
+  if [ "${hash_type}" -eq 14000 ]; then
+
+    min_len=7
+
+  fi
+
+  if [ "${hash_type}" -eq 14100 ]; then
+
+    min_len=23
+
+  fi
+
   # generate multiple pass/hash foreach len (2 to 8)
   if [ ${MODE} -ge 1 ]; then
 
@@ -612,8 +633,12 @@ function attack_1()
       offset=7
     elif [ ${hash_type} -eq 8500 ]; then
       offset=7
+    elif [ ${hash_type} -eq 14000 ]; then
+      offset=7
+    elif [ ${hash_type} -eq 14100 ]; then
+      offset=23
     fi
-
+ 
     hash_file=${OUTD}/${hash_type}_multihash_combi.txt
 
     tail -n ${offset} ${OUTD}/${hash_type}_hashes.txt > ${hash_file}
@@ -729,6 +754,20 @@ function attack_3()
 
     fi
 
+    if [ "${hash_type}" -eq 14000 ]; then
+
+      mask_offset=7
+      max=7
+
+    fi
+
+    if [ "${hash_type}" -eq 14100 ]; then
+
+      mask_offset=23
+      max=23
+  
+    fi
+
     i=1
 
     while read -u 9 hash; do
@@ -856,6 +895,20 @@ function attack_3()
 
     fi
 
+    if [ "${hash_type}" -eq 14000 ]; then
+
+      increment_min=8
+      increment_max=8
+
+    fi
+
+    if [ "${hash_type}" -eq 14100 ]; then
+
+      increment_min=24
+      increment_max=24
+
+    fi
+
     hash_file=${OUTD}/${hash_type}_multihash_bruteforce.txt
 
     head -n $((increment_max - ${increment_min} + 1)) ${OUTD}/${hash_type}_hashes.txt > ${hash_file}
@@ -1056,6 +1109,18 @@ function attack_6()
 
     fi
 
+    if [ "${hash_type}" -eq 14000 ]; then
+
+      max=6
+
+    fi
+
+    if [ "${hash_type}" -eq 14100 ]; then
+
+      max=6
+
+    fi
+
     while read -u 9 hash; do
 
       if [ "${i}" -gt 6 ]; then
@@ -1155,6 +1220,10 @@ function attack_6()
       max=8
     elif [ ${hash_type} -eq 8500 ]; then
       max=8
+    elif [ ${hash_type} -eq 14000 ]; then
+      max=5
+    elif [ ${hash_type} -eq 14100 ]; then
+      max=5
     fi
 
     if ! contains ${hash_type} ${TIMEOUT_ALGOS}; then
@@ -1280,6 +1349,18 @@ function attack_7()
 
     fi
 
+    if [ "${hash_type}" -eq 14000 ]; then
+
+      max=5
+
+    fi
+
+    if [ "${hash_type}" -eq 14100 ]; then
+
+      max=5
+
+    fi
+
     i=1
 
     while read -u 9 hash; do
@@ -1397,6 +1478,10 @@ function attack_7()
       max=8
     elif [ ${hash_type} -eq 8500 ]; then
       max=8
+    elif [ ${hash_type} -eq 14000 ]; then
+      max=5
+    elif [ ${hash_type} -eq 14100 ]; then
+      max=5
     fi
 
     if ! contains ${hash_type} ${TIMEOUT_ALGOS}; then
